import React, {useState, useContext, useEffect} from 'react';
import styled from 'styled-components'
import {Link} from 'react-router-dom'
import Breadcrumbs from '@material-ui/core/Breadcrumbs';
import {BreadcrumbsDiv, StyledBreadcrumbs} from './UserPage.js'
import Tabs from '@material-ui/core/Tabs'
import Tab from '@material-ui/core/Tab';
import Paper from '@material-ui/core/Paper';
import TabPanelEditarPerfil from '../Components/TabPanels/TabPanelEditarPerfil.js'
import TabPanelSolicitarContaProfessor from '../Components/TabPanels/TabPanelSolicitarContaProfessor.js'
import TabPanelGerenciarConta from '../Components/TabPanels/TabPanelGerenciarConta.js'

export default function EditProfilePage (props) {
    const [tabs, setTabs] = useState([
        'Editar Perfil', 'Solicitar conta de Professor', 'Gerenciar Conta'
    ])
    const [tabValue, setTabValue] = useState(0)
    const handleChangeTab = (e, newValue) => {
        setTabValue(newValue)
    }

    return (
        <div style={{backgroundColor:"#f4f4f4", color:"#666"}}>
            <BreadcrumbsDiv>
                <StyledBreadcrumbs>
                    <Link to="/" style={{color:"#00bcd4", textDecoration:"none"}}>
                        Página Inicial
                    </Link>
                    <span>
                        Minha área
                    </span>
                    <span>
                        Configurações da Conta
                    </span>
                    <span>
                        {tabs[tabValue]}
                    </span>
                </StyledBreadcrumbs>
            </BreadcrumbsDiv>

            <MainContainerDiv>
                <div style={{width : "auto", fontFamily:"Roboto"}}>
                    <Paper elevation={3} style= {{width:"max-content"}}>
                        <ConfiguracoesMenu>
                            <h4 style={{marginTop:"10px", fontFamily:"inherit", display:"flex", justifyContent:"center"}}>
                            Configurações da Conta
                            </h4>
                            <StyledTabs
                                orientation = "vertical"
                                variant = "scrollable"
                                value = {tabValue}
                                onChange = {handleChangeTab}
                                TabIndicatorProps = {{style : {display : "none"}}}
                            >
                                <StyledTab label={tabs[0]}/>
                                <StyledTab label={tabs[1]}/>
                                <StyledTab label={tabs[2]}/>
                            </StyledTabs>
                        </ConfiguracoesMenu>
                    </Paper>
                </div>
                <div style={{width : "auto", paddingLeft:"1em"}}>
                    <Paper elevation={3} style= {{width:"max-content"}}>
                        {tabValue === 0 && <TabPanelEditarPerfil/>}
                        {tabValue === 1 && <TabPanelSolicitarContaProfessor/>}
                        {tabValue === 2 && <TabPanelGerenciarConta/>}
                    </Paper>
                </div>
            </MainContainerDiv>
        </div>
    )
}

const StyledTabs = styled(Tabs)`
    .Mui-selected {
        background-color : #f4f4f4;
    }
`

const StyledTab = styled(Tab)`
    &:hover {
        background-color : #6666663d;
    }
`

const ConfiguracoesMenu = styled.div`
    margin : 20px 0 20px 0;
    border-radius : 3px;
    padding : 20px 0;
    background-color : #fff;
    text-align : start;
`

const MainContainerDiv = styled.div`
    padding : 0;
    width : 1170;
    margin-right : auto;
    margin-left : auto;
    display : flex;
    flex-direction : row;
    align-content : center;
    justify-content : center;
`
